package com.vetti.hotake.mapper;

import java.util.List;
import com.vetti.hotake.domain.HotakeReferenceCheck;

/**
 * 参考检查Mapper接口
 * 
 * @author sxc
 * @date 2026-01-29
 */
public interface HotakeReferenceCheckMapper 
{
    /**
     * 查询参考检查
     * 
     * @param id 参考检查主键
     * @return 参考检查
     */
    public HotakeReferenceCheck selectHotakeReferenceCheckById(Integer id);

    /**
     * 查询参考检查列表
     * 
     * @param hotakeReferenceCheck 参考检查
     * @return 参考检查集合
     */
    public List<HotakeReferenceCheck> selectHotakeReferenceCheckList(HotakeReferenceCheck hotakeReferenceCheck);

    /**
     * 新增参考检查
     * 
     * @param hotakeReferenceCheck 参考检查
     * @return 结果
     */
    public int insertHotakeReferenceCheck(HotakeReferenceCheck hotakeReferenceCheck);

    /**
     * 批量新增参考检查
     * 
     * @param hotakeReferenceCheckList 参考检查列表
     * @return 结果
     */
    public int batchInsertHotakeReferenceCheck(List<HotakeReferenceCheck> hotakeReferenceCheckList);

    /**
     * 修改参考检查
     * 
     * @param hotakeReferenceCheck 参考检查
     * @return 结果
     */
    public int updateHotakeReferenceCheck(HotakeReferenceCheck hotakeReferenceCheck);

    /**
     * 删除参考检查
     * 
     * @param id 参考检查主键
     * @return 结果
     */
    public int deleteHotakeReferenceCheckById(Integer id);

    /**
     * 批量删除参考检查
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteHotakeReferenceCheckByIds(Integer[] ids);
}
